==> 1.6-15.10.11.tar.gz: 1.6/map.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#       unbenannt.py
#       
#       Copyright 2011 Johannes ter Haak <jojo@jojo3>
#       
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

"""
world=[]
for i in range(0,5):
	world.append([])
	for i2 in range(0,10):
		world[i].append([(i,i2),"weg-h-3.png"])

print world
print "---"
print world[1][2]

datei_map = open("map.txt","w",1)

for o in world:
	for o2 in o:
		write = "{("+str(o2[0][0])+","+str(o2[0][1])+");"+'"'+o2[1]+'"'+"}"
		datei_map.write(write)
datei_map.close()
"""
world=[]
for x  in range(0,15):
	world.append([])
	for y in range(0,20):
		world[-1].append({"pos":[x,y],"datei":"bild/wiese-3.png","size":[1,1],"type":1,"bauen":1})
		if (1 < x < 5) and (1 < y < 5):
			world[-1][-1]["link"] = [2,2]
		if (x == 2) and (y == 2):
			world[-1][-1]["link"] = None
			world[-1][-1]["datei"] = "bild/haus-6.png"
			world[-1][-1]["size"] = [3,3]
			world[-1][-1]["type"] = 10
			world[-1][-1]["bauen"] = 0

			 
			 
del x,y	
print world[4][7]

datei_map = open("map.txt","w",1)

for col in world:
	for obj in col:
		posstr = "pos=(" + str(obj["pos"][0]) + "," + str(obj["pos"][1]) + ");"
		if obj.get("link") != None:
			dateistr='link=('+ str(obj["link"][0]) + "," + str(obj["link"][1]) +')'
			sizestr=""
			typestr=""
			bauenstr=""
		else:
			dateistr = 'datei="' + obj["datei"] + '";'
			sizestr= "size=("+ str(obj["size"][0]) + "," + str(obj["size"][1]) +');'
			typestr= "type="+ str(obj["type"]) + ";"
			bauenstr="bauen="+str(obj["bauen"])
		save = "{" + posstr + dateistr + sizestr + typestr + bauenstr+"}"
		datei_map.write(save)
		

datei_map.close()

==> 1.7-25.10.11.tar.gz: 1.7/map.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#       unbenannt.py
#       
#       Copyright 2011 Johannes ter Haak <jojo@jojo3>
#       
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#       
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#       
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

"""
world=[]
for i in range(0,5):
	world.append([])
	for i2 in range(0,10):
		world[i].append([(i,i2),"weg-h-3.png"])

print world
print "---"
print world[1][2]

datei_map = open("map.txt","w",1)

for o in world:
	for o2 in o:
		write = "{("+str(o2[0][0])+","+str(o2[0][1])+");"+'"'+o2[1]+'"'+"}"
		datei_map.write(write)
datei_map.close()
"""
world=[]
for x  in range(0,20):
	world.append([])
	for y in range(0,20):
		world[-1].append({"pos":[x,y],"datei":"bild/wiese-z2-n.png","size":[1,1],"type":1,"bauen":1})
		if (1 < x < 5) and (1 < y < 5):
			world[-1][-1]["link"] = [2,2]
		if (x == 2) and (y == 2):
			world[-1][-1]["link"] = None
			world[-1][-1]["datei"] = "bild/haus-lvl0-z2-n.png"
			world[-1][-1]["size"] = [3,3]
			world[-1][-1]["type"] = 10
			world[-1][-1]["bauen"] = 0

			 
			 
del x,y	
print world[4][7]

datei_map = open("map.txt","w",1)

for col in world:
	for obj in col:
		posstr = "pos=(" + str(obj["pos"][0]) + "," + str(obj["pos"][1]) + ");"
		if obj.get("link") != None:
			dateistr='link=('+ str(obj["link"][0]) + "," + str(obj["link"][1]) +')'
			sizestr=""
			typestr=""
			bauenstr=""
		else:
			dateistr = 'datei="' + obj["datei"] + '";'
			sizestr= "size=("+ str(obj["size"][0]) + "," + str(obj["size"][1]) +');'
			typestr= "type="+ str(obj["type"]) + ";"
			bauenstr="bauen="+str(obj["bauen"])
		save = "{" + posstr + dateistr + sizestr + typestr + bauenstr+"}"
		datei_map.write(save)
		

datei_map.close()
